# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.api.instances_api import InstancesApi


class TestInstancesApi(unittest.TestCase):
    """InstancesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InstancesApi()

    def tearDown(self) -> None:
        pass

    def test_create_wds_instance(self) -> None:
        """Test case for create_wds_instance

        Create an instance
        """
        pass

    def test_delete_wds_instance(self) -> None:
        """Test case for delete_wds_instance

        Delete an instance
        """
        pass

    def test_list_wds_instances(self) -> None:
        """Test case for list_wds_instances

        List instances
        """
        pass


if __name__ == '__main__':
    unittest.main()
