# coding: utf-8

"""
    Workspace Data Service

    This page lists current APIs.  All v0.2 APIs are subject to change without notice.  Changelog at [https://github.com/DataBiosphere/terra-workspace-data-service/releases](https://github.com/DataBiosphere/terra-workspace-data-service/releases) 

    The version of the OpenAPI document: v0.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wds_client.models.attribute_data_type import AttributeDataType

class TestAttributeDataType(unittest.TestCase):
    """AttributeDataType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAttributeDataType(self):
        """Test AttributeDataType"""
        # inst = AttributeDataType()

if __name__ == '__main__':
    unittest.main()
